package org.rcisoft.integration.video.utils;

import com.sun.jna.Pointer;
import com.sun.jna.ptr.IntByReference;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.integration.video.common.VideoDeviceSDKComm;
import org.rcisoft.integration.video.config.DaHuaVideoInitConfig;
import org.rcisoft.integration.video.lib.NetSDKLib;

/**
 * 抓图工具类
 */
@Slf4j
public class CapturePictureUtils {

    /**
     * 本地抓图
     */
    public static boolean localCapturePicture(NetSDKLib.LLong hPlayHandle, String picFileName) {

        if (!DaHuaVideoInitConfig.netsdk.CLIENT_CapturePictureEx(hPlayHandle, picFileName, NetSDKLib.NET_CAPTURE_FORMATS.NET_CAPTURE_JPEG)) {
            log.error("CLIENT_CapturePicture Failed!："+ VideoDeviceSDKComm.getErrorCodePrint());
            return false;
        } else {
            log.debug("CLIENT_CapturePicture success");
        }
        return true;
    }

    /**
     * 远程抓图
     */
    public static boolean remoteCapturePicture(NetSDKLib.LLong m_hLoginHandle,int chn) {
        return snapPicture(m_hLoginHandle,chn, 0, 0);
    }

    /**
     * 定时抓图
     */
    public static boolean timerCapturePicture(NetSDKLib.LLong m_hLoginHandle,int chn) {
        return snapPicture(m_hLoginHandle,chn, 1, 2);
    }

    /**
     * 停止定时抓图
     */
    public static boolean stopCapturePicture(NetSDKLib.LLong m_hLoginHandle,int chn) {
        return snapPicture(m_hLoginHandle,chn, -1, 0);
    }

    /**
     * 抓图 (除本地抓图外, 其他全部调用此接口)
     */
    private static boolean snapPicture(NetSDKLib.LLong m_hLoginHandle, int chn, int mode, int interval) {
        // send caputre picture command to device
        NetSDKLib.SNAP_PARAMS stuSnapParams = new NetSDKLib.SNAP_PARAMS();
        stuSnapParams.Channel = chn;  			// channel
        stuSnapParams.mode = mode;    			// capture picture mode
        stuSnapParams.Quality = 3;				// picture quality
        stuSnapParams.InterSnap = interval; 	// timer capture picture time interval
        stuSnapParams.CmdSerial = 0;  			// request serial

        IntByReference reserved = new IntByReference(0);
        if (!DaHuaVideoInitConfig.netsdk.CLIENT_SnapPictureEx(m_hLoginHandle, stuSnapParams, reserved)) {
            log.error("CLIENT_SnapPictureEx Failed!"+VideoDeviceSDKComm.getErrorCodePrint());
            return false;
        } else {
            log.debug("CLIENT_SnapPictureEx success");
        }
        return true;
    }




    /**
     * 设置抓图回调函数
     */
    public static void setSnapRevCallBack(NetSDKLib.fSnapRev cbSnapReceive){
        DaHuaVideoInitConfig.netsdk.CLIENT_SetSnapRevCallBack(cbSnapReceive, null);
    }

    /**
     * 设置抓图回调函数
     */
    public static void setSnapRevCallBack(NetSDKLib.fSnapRev cbSnapReceive, Pointer data){
        DaHuaVideoInitConfig.netsdk.CLIENT_SetSnapRevCallBack(cbSnapReceive, data);
    }


}
